@@ -39,35 +39,14 @@ class _Language(Enum):
                 return cls.__get_language(default)
 
 
-class GCC(Processor):
-    'GNU project C, C++ and Go compiler'
+class Bash(Processor):
+    "Bash is the GNU Project's Bourne Again SHell"
 
-    class Language(_Language):
-        'Programming language, C, C++ or Go'
-        c = 'C'
-        cpp = 'C++'
-        go = 'Go'
-
-        @classmethod
-        def _get_language(cls, language):
-            return super().__get_language(language, cls.cpp)
-
-    def __init__(self, language=None, version=None,
-                 filenames=None, options=None):
-        lang = self.Language._get_language(language)
-        fns = filenames or {}
-        args = options or []
-
-        self.image = self._get_image_with_tag('gcc', version)
-        self.source = fns.get('src', f'a.{lang.name}')
-        self.compile = ([{self.Language.c: 'gcc',
-                          self.Language.cpp: 'g++',
-                          self.Language.go: 'gccgo'}[lang],
-                         self.source]
-                        + (['-o', fns['bin']]
-                           if fns.get('bin') else []) + args)
-        self.after_compile = ['rm', self.source]
-        self.judge = f"./{fns.get('bin', 'a.out')}"
+    def __init__(self, version=None):
+        self.image = self._get_image_with_tag('bash', version)
+        self.source = 'bash.sh'
+        self.compile = ['bash', '-n', self.source]
+        self.judge = f'sh {self.source}'
 
 
 class Clang(Processor):
@@ -99,14 +78,35 @@ class Clang(Processor):
         self.judge = f"./{fns.get('bin', 'a.out')}"
 
 
-class Python(Processor):
-    'CPython'
+class GCC(Processor):
+    'GNU project C, C++ and Go compiler'
 
-    def __init__(self, version=None):
-        self.image = self._get_image_with_tag('python', version)
-        self.source = '__init__.py'
-        self.compile = ['python', '-m', 'compileall', '.']
-        self.judge = f'python {self.source}'
+    class Language(_Language):
+        'Programming language, C, C++ or Go'
+        c = 'C'
+        cpp = 'C++'
+        go = 'Go'
+
+        @classmethod
+        def _get_language(cls, language):
+            return super().__get_language(language, cls.cpp)
+
+    def __init__(self, language=None, version=None,
+                 filenames=None, options=None):
+        lang = self.Language._get_language(language)
+        fns = filenames or {}
+        args = options or []
+
+        self.image = self._get_image_with_tag('gcc', version)
+        self.source = fns.get('src', f'a.{lang.name}')
+        self.compile = ([{self.Language.c: 'gcc',
+                          self.Language.cpp: 'g++',
+                          self.Language.go: 'gccgo'}[lang],
+                         self.source]
+                        + (['-o', fns['bin']]
+                           if fns.get('bin') else []) + args)
+        self.after_compile = ['rm', self.source]
+        self.judge = f"./{fns.get('bin', 'a.out')}"
 
 
 class Go(Processor):
@@ -126,6 +126,16 @@ class Go(Processor):
         self.judge = f"./{fns.get('bin', 'main')}"
 
 
+class Node(Processor):
+    'Node.js®'
+
+    def __init__(self, version=None):
+        self.image = self._get_image_with_tag('node', version)
+        self.source = 'index.js'
+        self.compile = ['node', '-c', self.source]
+        self.judge = f'node {self.source}'
+
+
 class OpenJDK(Processor):
     'Open Java Development Kit'
 
@@ -137,11 +147,11 @@ class OpenJDK(Processor):
         self.judge = 'java Main'
 
 
-class Node(Processor):
-    'Node.js®'
+class Python(Processor):
+    'CPython'
 
     def __init__(self, version=None):
-        self.image = self._get_image_with_tag('node', version)
-        self.source = 'index.js'
-        self.compile = ['node', '-c', self.source]
-        self.judge = f'node {self.source}'
+        self.image = self._get_image_with_tag('python', version)
+        self.source = '__init__.py'
+        self.compile = ['python', '-m', 'compileall', '.']
+        self.judge = f'python {self.source}'
